# tictactoetools

tictactoetools is a Python package that provides functionality for building games of Tic-Tac-Toe with customizable features
and storing the data of matches in a database.

# Installation

To install the tictactoetools package, you can use the following command:

```
pip install tictactools
```

# Usage

The tictactoetools module within the package comes with a builtin play() method as an example for playing tic-tac-toe using
the given features.

The tictactoetools module also has functions for creating new users in the tictactoe.db database, logging matches in the
database, starting new matches, and even prompting values from the user for playing Tic-Tac-Toe.

### Board Class

The Board class represents the Tic-Tac-Toe game board. It provides methods for displaying the board, marking cells with
any symbol, checking for a winner, and more.

### Match Class

The Match class is a data class responsible for storing information about the players, start and end times of a match,
the board configuration, and the winner.

# Contributing

Contributions to the tictactoetools package are welcome! If you encounter any issues or have suggestions for improvements,
please create an issue on the GitHub repository.

# License

This package is licensed under the MIT License. See the LICENSE file for more information.